@@ -6,10 +6,10 @@ __email__ = u'ctrueden@gmail.com'
 __copyright__ = u'Public domain'
 __license__ = u'License :: OSI Approved :: Unlicense'
 
-__version__ = u'1.0.0'
+__version__ = u'1.1.0'
 __status__ = u'Stable'
 
 __PACKAGE_TITLE__ = u'iBroadcast'
 __PACKAGE_NAME__ = u'ibroadcast'
-__PACKAGE_DESCRIPTION__ = u'iBroadcast Python client',
+__PACKAGE_DESCRIPTION__ = u'iBroadcast Python client'
 __PACKAGE_URL__ = u'https://github.com/ctrueden/ibroadcast-python'
